from module import mqtt_test_client, init_state, state_change_by_mqtt
from devices import silvercrest_motion_sensor as test_device
from devices.base import warning
from mqtt import mqtt_client
import pytest
import time

DUT_CLIENT_ID = "__%s__" % __name__
TOPIC = "__test__/%s" % __name__
#
MQTT_SIGNAL_TIME = 0.2


ALL_STATE_KEYS = ["battery", "battery_low", "linkquality", "occupancy", "tamper", "voltage"]
BOOL_KEYS = ["battery_low", "occupancy", "tamper"]


@pytest.fixture
def this_device():
    mc = mqtt_client(DUT_CLIENT_ID, 'localhost')
    return test_device(mc, TOPIC)


def test_initial_states(this_device: test_device):
    # test all initial values
    init_state(ALL_STATE_KEYS, this_device)


def test_state_change_by_mqtt(this_device: test_device):
    def state_data(key):
        if key in BOOL_KEYS:
            return (True, False)
        elif key == "battery":
            return (2, 87)
        elif key == "linkquality":
            return (1, 217)
        elif key == "voltage":
            return (1.17, 2.53)
        else:
            raise IndexError("No return value defined for key %s" % key)

    def mqtt_data(key):
        return state_data(key)

    def warning_condition(state_topic, value):
        return state_topic == "battery_low" and value is True

    # test state changes
    tm_warning = state_change_by_mqtt(ALL_STATE_KEYS, 2, mqtt_test_client, TOPIC, this_device,
                                      mqtt_data, state_data, None, MQTT_SIGNAL_TIME)


def test_specific_get_functions(this_device: test_device):
    assert this_device.linkquality == this_device.get(this_device.KEY_LINKQUALITY)
    assert this_device.battery == this_device.get(this_device.KEY_BATTERY)
